# Welcome to pyosPackage's documentation

:::{toctree}
:maxdepth: 2
:caption: Contents:

home <self>
hatch scripts <hatch-envs-scripts>
Setup Sphinx <documentation/setup-sphinx>
Reference / API <apidocs/index>
:::

:::{toctree}
:maxdepth: 2
:caption: Contents:

:::

This guidebook uses myst as the primary documentation syntax.

more about myst here....

If you see syntax like the syntax below, you are looking at rst.

```
.. toctree::
   :maxdepth: 2
   :caption: Contents:
```

:::{note}
you can remove the `make.bat` and `Makefile` files included with sphinx build.
:::
